@@ -1,5 +1,7 @@
 """
-Main interface for swf service client
+Type annotations for swf service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
@@ -15,7 +17,8 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_swf.paginator import (
+from .literals import ChildPolicyType, RegistrationStatusType
+from .paginator import (
     GetWorkflowExecutionHistoryPaginator,
     ListActivityTypesPaginator,
     ListClosedWorkflowExecutionsPaginator,
@@ -24,7 +27,7 @@ from mypy_boto3_swf.paginator import (
     ListWorkflowTypesPaginator,
     PollForDecisionTaskPaginator,
 )
-from mypy_boto3_swf.type_defs import (
+from .type_defs import (
     ActivityTaskStatusTypeDef,
     ActivityTaskTypeDef,
     ActivityTypeDetailTypeDef,
@@ -87,7 +90,8 @@ class Exceptions:
 
 class SWFClient:
     """
-    [SWF.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -95,7 +99,8 @@ class SWFClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def count_closed_workflow_executions(
@@ -109,7 +114,8 @@ class SWFClient:
         closeStatusFilter: CloseStatusFilterTypeDef = None,
     ) -> WorkflowExecutionCountTypeDef:
         """
-        [Client.count_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
+        [Show boto3-stubs documentation](./client.md#count_closed_workflow_executions)
         """
 
     def count_open_workflow_executions(
@@ -121,62 +127,72 @@ class SWFClient:
         executionFilter: WorkflowExecutionFilterTypeDef = None,
     ) -> WorkflowExecutionCountTypeDef:
         """
-        [Client.count_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
+        [Show boto3-stubs documentation](./client.md#count_open_workflow_executions)
         """
 
     def count_pending_activity_tasks(
         self, domain: str, taskList: "TaskListTypeDef"
     ) -> PendingTaskCountTypeDef:
         """
-        [Client.count_pending_activity_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
+        [Show boto3-stubs documentation](./client.md#count_pending_activity_tasks)
         """
 
     def count_pending_decision_tasks(
         self, domain: str, taskList: "TaskListTypeDef"
     ) -> PendingTaskCountTypeDef:
         """
-        [Client.count_pending_decision_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
+        [Show boto3-stubs documentation](./client.md#count_pending_decision_tasks)
         """
 
     def deprecate_activity_type(self, domain: str, activityType: "ActivityTypeTypeDef") -> None:
         """
-        [Client.deprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.deprecate_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.deprecate_activity_type)
+        [Show boto3-stubs documentation](./client.md#deprecate_activity_type)
         """
 
     def deprecate_domain(self, name: str) -> None:
         """
-        [Client.deprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.deprecate_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.deprecate_domain)
+        [Show boto3-stubs documentation](./client.md#deprecate_domain)
         """
 
     def deprecate_workflow_type(self, domain: str, workflowType: "WorkflowTypeTypeDef") -> None:
         """
-        [Client.deprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
+        [Show boto3-stubs documentation](./client.md#deprecate_workflow_type)
         """
 
     def describe_activity_type(
         self, domain: str, activityType: "ActivityTypeTypeDef"
     ) -> ActivityTypeDetailTypeDef:
         """
-        [Client.describe_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.describe_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.describe_activity_type)
+        [Show boto3-stubs documentation](./client.md#describe_activity_type)
         """
 
     def describe_domain(self, name: str) -> DomainDetailTypeDef:
         """
-        [Client.describe_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.describe_domain)
+        [Show boto3-stubs documentation](./client.md#describe_domain)
         """
 
     def describe_workflow_execution(
         self, domain: str, execution: "WorkflowExecutionTypeDef"
     ) -> WorkflowExecutionDetailTypeDef:
         """
-        [Client.describe_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.describe_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.describe_workflow_execution)
+        [Show boto3-stubs documentation](./client.md#describe_workflow_execution)
         """
 
     def describe_workflow_type(
         self, domain: str, workflowType: "WorkflowTypeTypeDef"
     ) -> WorkflowTypeDetailTypeDef:
         """
-        [Client.describe_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.describe_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.describe_workflow_type)
+        [Show boto3-stubs documentation](./client.md#describe_workflow_type)
         """
 
     def generate_presigned_url(
@@ -187,7 +203,8 @@ class SWFClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_workflow_execution_history(
@@ -199,20 +216,22 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> HistoryTypeDef:
         """
-        [Client.get_workflow_execution_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
+        [Show boto3-stubs documentation](./client.md#get_workflow_execution_history)
         """
 
     def list_activity_types(
         self,
         domain: str,
-        registrationStatus: Literal["REGISTERED", "DEPRECATED"],
+        registrationStatus: RegistrationStatusType,
         name: str = None,
         nextPageToken: str = None,
         maximumPageSize: int = None,
         reverseOrder: bool = None,
     ) -> ActivityTypeInfosTypeDef:
         """
-        [Client.list_activity_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.list_activity_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.list_activity_types)
+        [Show boto3-stubs documentation](./client.md#list_activity_types)
         """
 
     def list_closed_workflow_executions(
@@ -229,18 +248,20 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> WorkflowExecutionInfosTypeDef:
         """
-        [Client.list_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
+        [Show boto3-stubs documentation](./client.md#list_closed_workflow_executions)
         """
 
     def list_domains(
         self,
-        registrationStatus: Literal["REGISTERED", "DEPRECATED"],
+        registrationStatus: RegistrationStatusType,
         nextPageToken: str = None,
         maximumPageSize: int = None,
         reverseOrder: bool = None,
     ) -> DomainInfosTypeDef:
         """
-        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.list_domains)
+        [Show boto3-stubs documentation](./client.md#list_domains)
         """
 
     def list_open_workflow_executions(
@@ -255,32 +276,36 @@ class SWFClient:
         executionFilter: WorkflowExecutionFilterTypeDef = None,
     ) -> WorkflowExecutionInfosTypeDef:
         """
-        [Client.list_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
+        [Show boto3-stubs documentation](./client.md#list_open_workflow_executions)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceOutputTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_workflow_types(
         self,
         domain: str,
-        registrationStatus: Literal["REGISTERED", "DEPRECATED"],
+        registrationStatus: RegistrationStatusType,
         name: str = None,
         nextPageToken: str = None,
         maximumPageSize: int = None,
         reverseOrder: bool = None,
     ) -> WorkflowTypeInfosTypeDef:
         """
-        [Client.list_workflow_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.list_workflow_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.list_workflow_types)
+        [Show boto3-stubs documentation](./client.md#list_workflow_types)
         """
 
     def poll_for_activity_task(
         self, domain: str, taskList: "TaskListTypeDef", identity: str = None
     ) -> ActivityTaskTypeDef:
         """
-        [Client.poll_for_activity_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.poll_for_activity_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.poll_for_activity_task)
+        [Show boto3-stubs documentation](./client.md#poll_for_activity_task)
         """
 
     def poll_for_decision_task(
@@ -293,14 +318,16 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> DecisionTaskTypeDef:
         """
-        [Client.poll_for_decision_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.poll_for_decision_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.poll_for_decision_task)
+        [Show boto3-stubs documentation](./client.md#poll_for_decision_task)
         """
 
     def record_activity_task_heartbeat(
         self, taskToken: str, details: str = None
     ) -> ActivityTaskStatusTypeDef:
         """
-        [Client.record_activity_task_heartbeat documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
+        [Show boto3-stubs documentation](./client.md#record_activity_task_heartbeat)
         """
 
     def register_activity_type(
@@ -317,7 +344,8 @@ class SWFClient:
         defaultTaskScheduleToCloseTimeout: str = None,
     ) -> None:
         """
-        [Client.register_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.register_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.register_activity_type)
+        [Show boto3-stubs documentation](./client.md#register_activity_type)
         """
 
     def register_domain(
@@ -328,7 +356,8 @@ class SWFClient:
         tags: List["ResourceTagTypeDef"] = None,
     ) -> None:
         """
-        [Client.register_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.register_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.register_domain)
+        [Show boto3-stubs documentation](./client.md#register_domain)
         """
 
     def register_workflow_type(
@@ -341,49 +370,56 @@ class SWFClient:
         defaultExecutionStartToCloseTimeout: str = None,
         defaultTaskList: "TaskListTypeDef" = None,
         defaultTaskPriority: str = None,
-        defaultChildPolicy: Literal["TERMINATE", "REQUEST_CANCEL", "ABANDON"] = None,
+        defaultChildPolicy: ChildPolicyType = None,
         defaultLambdaRole: str = None,
     ) -> None:
         """
-        [Client.register_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.register_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.register_workflow_type)
+        [Show boto3-stubs documentation](./client.md#register_workflow_type)
         """
 
     def request_cancel_workflow_execution(
         self, domain: str, workflowId: str, runId: str = None
     ) -> None:
         """
-        [Client.request_cancel_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
+        [Show boto3-stubs documentation](./client.md#request_cancel_workflow_execution)
         """
 
     def respond_activity_task_canceled(self, taskToken: str, details: str = None) -> None:
         """
-        [Client.respond_activity_task_canceled documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
+        [Show boto3-stubs documentation](./client.md#respond_activity_task_canceled)
         """
 
     def respond_activity_task_completed(self, taskToken: str, result: str = None) -> None:
         """
-        [Client.respond_activity_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
+        [Show boto3-stubs documentation](./client.md#respond_activity_task_completed)
         """
 
     def respond_activity_task_failed(
         self, taskToken: str, reason: str = None, details: str = None
     ) -> None:
         """
-        [Client.respond_activity_task_failed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
+        [Show boto3-stubs documentation](./client.md#respond_activity_task_failed)
         """
 
     def respond_decision_task_completed(
         self, taskToken: str, decisions: List[DecisionTypeDef] = None, executionContext: str = None
     ) -> None:
         """
-        [Client.respond_decision_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
+        [Show boto3-stubs documentation](./client.md#respond_decision_task_completed)
         """
 
     def signal_workflow_execution(
         self, domain: str, workflowId: str, signalName: str, runId: str = None, input: str = None
     ) -> None:
         """
-        [Client.signal_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.signal_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.signal_workflow_execution)
+        [Show boto3-stubs documentation](./client.md#signal_workflow_execution)
         """
 
     def start_workflow_execution(
@@ -397,16 +433,18 @@ class SWFClient:
         executionStartToCloseTimeout: str = None,
         tagList: List[str] = None,
         taskStartToCloseTimeout: str = None,
-        childPolicy: Literal["TERMINATE", "REQUEST_CANCEL", "ABANDON"] = None,
+        childPolicy: ChildPolicyType = None,
         lambdaRole: str = None,
     ) -> RunTypeDef:
         """
-        [Client.start_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.start_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.start_workflow_execution)
+        [Show boto3-stubs documentation](./client.md#start_workflow_execution)
         """
 
     def tag_resource(self, resourceArn: str, tags: List["ResourceTagTypeDef"]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def terminate_workflow_execution(
@@ -416,30 +454,35 @@ class SWFClient:
         runId: str = None,
         reason: str = None,
         details: str = None,
-        childPolicy: Literal["TERMINATE", "REQUEST_CANCEL", "ABANDON"] = None,
+        childPolicy: ChildPolicyType = None,
     ) -> None:
         """
-        [Client.terminate_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
+        [Show boto3-stubs documentation](./client.md#terminate_workflow_execution)
         """
 
     def undeprecate_activity_type(self, domain: str, activityType: "ActivityTypeTypeDef") -> None:
         """
-        [Client.undeprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
+        [Show boto3-stubs documentation](./client.md#undeprecate_activity_type)
         """
 
     def undeprecate_domain(self, name: str) -> None:
         """
-        [Client.undeprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.undeprecate_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.undeprecate_domain)
+        [Show boto3-stubs documentation](./client.md#undeprecate_domain)
         """
 
     def undeprecate_workflow_type(self, domain: str, workflowType: "WorkflowTypeTypeDef") -> None:
         """
-        [Client.undeprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
+        [Show boto3-stubs documentation](./client.md#undeprecate_workflow_type)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     @overload
@@ -447,7 +490,7 @@ class SWFClient:
         self, operation_name: Literal["get_workflow_execution_history"]
     ) -> GetWorkflowExecutionHistoryPaginator:
         """
-        [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)[Show boto3-stubs documentation](./paginators.md#getworkflowexecutionhistorypaginator)
         """
 
     @overload
@@ -455,7 +498,7 @@ class SWFClient:
         self, operation_name: Literal["list_activity_types"]
     ) -> ListActivityTypesPaginator:
         """
-        [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListActivityTypes)[Show boto3-stubs documentation](./paginators.md#listactivitytypespaginator)
         """
 
     @overload
@@ -463,13 +506,13 @@ class SWFClient:
         self, operation_name: Literal["list_closed_workflow_executions"]
     ) -> ListClosedWorkflowExecutionsPaginator:
         """
-        [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)[Show boto3-stubs documentation](./paginators.md#listclosedworkflowexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListDomains)[Show boto3-stubs documentation](./paginators.md#listdomainspaginator)
         """
 
     @overload
@@ -477,7 +520,7 @@ class SWFClient:
         self, operation_name: Literal["list_open_workflow_executions"]
     ) -> ListOpenWorkflowExecutionsPaginator:
         """
-        [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)[Show boto3-stubs documentation](./paginators.md#listopenworkflowexecutionspaginator)
         """
 
     @overload
@@ -485,7 +528,7 @@ class SWFClient:
         self, operation_name: Literal["list_workflow_types"]
     ) -> ListWorkflowTypesPaginator:
         """
-        [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)[Show boto3-stubs documentation](./paginators.md#listworkflowtypespaginator)
         """
 
     @overload
@@ -493,5 +536,5 @@ class SWFClient:
         self, operation_name: Literal["poll_for_decision_task"]
     ) -> PollForDecisionTaskPaginator:
         """
-        [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)[Show boto3-stubs documentation](./paginators.md#pollfordecisiontaskpaginator)
         """
