@@ -1,5 +1,7 @@
 """
-Main interface for swf service client paginators.
+Type annotations for swf service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -28,12 +30,12 @@ Usage::
     poll_for_decision_task_paginator: PollForDecisionTaskPaginator = client.get_paginator("poll_for_decision_task")
     ```
 """
-import sys
 from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_swf.type_defs import (
+from .literals import RegistrationStatusType
+from .type_defs import (
     ActivityTypeInfosTypeDef,
     CloseStatusFilterTypeDef,
     DecisionTaskTypeDef,
@@ -50,12 +52,6 @@ from mypy_boto3_swf.type_defs import (
     WorkflowTypeInfosTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "GetWorkflowExecutionHistoryPaginator",
     "ListActivityTypesPaginator",
@@ -69,7 +65,7 @@ __all__ = (
 
 class GetWorkflowExecutionHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)[Show boto3-stubs documentation](./paginators.md#getworkflowexecutionhistorypaginator)
     """
 
     def paginate(
@@ -80,31 +76,33 @@ class GetWorkflowExecutionHistoryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[HistoryTypeDef]:
         """
-        [GetWorkflowExecutionHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory.paginate)
+        [Show boto3-stubs documentation](./paginators.md#getworkflowexecutionhistorypaginator)
         """
 
 
 class ListActivityTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListActivityTypes)[Show boto3-stubs documentation](./paginators.md#listactivitytypespaginator)
     """
 
     def paginate(
         self,
         domain: str,
-        registrationStatus: Literal["REGISTERED", "DEPRECATED"],
+        registrationStatus: RegistrationStatusType,
         name: str = None,
         reverseOrder: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ActivityTypeInfosTypeDef]:
         """
-        [ListActivityTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListActivityTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListActivityTypes.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listactivitytypespaginator)
         """
 
 
 class ListClosedWorkflowExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)[Show boto3-stubs documentation](./paginators.md#listclosedworkflowexecutionspaginator)
     """
 
     def paginate(
@@ -120,29 +118,31 @@ class ListClosedWorkflowExecutionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[WorkflowExecutionInfosTypeDef]:
         """
-        [ListClosedWorkflowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listclosedworkflowexecutionspaginator)
         """
 
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListDomains)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListDomains)[Show boto3-stubs documentation](./paginators.md#listdomainspaginator)
     """
 
     def paginate(
         self,
-        registrationStatus: Literal["REGISTERED", "DEPRECATED"],
+        registrationStatus: RegistrationStatusType,
         reverseOrder: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DomainInfosTypeDef]:
         """
-        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListDomains.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListDomains.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listdomainspaginator)
         """
 
 
 class ListOpenWorkflowExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)[Show boto3-stubs documentation](./paginators.md#listopenworkflowexecutionspaginator)
     """
 
     def paginate(
@@ -156,31 +156,33 @@ class ListOpenWorkflowExecutionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[WorkflowExecutionInfosTypeDef]:
         """
-        [ListOpenWorkflowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listopenworkflowexecutionspaginator)
         """
 
 
 class ListWorkflowTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)[Show boto3-stubs documentation](./paginators.md#listworkflowtypespaginator)
     """
 
     def paginate(
         self,
         domain: str,
-        registrationStatus: Literal["REGISTERED", "DEPRECATED"],
+        registrationStatus: RegistrationStatusType,
         name: str = None,
         reverseOrder: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[WorkflowTypeInfosTypeDef]:
         """
-        [ListWorkflowTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listworkflowtypespaginator)
         """
 
 
 class PollForDecisionTaskPaginator(Boto3Paginator):
     """
-    [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)[Show boto3-stubs documentation](./paginators.md#pollfordecisiontaskpaginator)
     """
 
     def paginate(
@@ -192,5 +194,6 @@ class PollForDecisionTaskPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DecisionTaskTypeDef]:
         """
-        [PollForDecisionTask.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/swf.html#SWF.Paginator.PollForDecisionTask.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/swf.html#SWF.Paginator.PollForDecisionTask.paginate)
+        [Show boto3-stubs documentation](./paginators.md#pollfordecisiontaskpaginator)
         """
